@@ -1,7 +1,6 @@
 import re
 import os
 import kfp
-import yaml
 import json
 import kfp.dsl as dsl
 from kfp import compiler
@@ -29,7 +28,7 @@ if __name__ == '__main__':
 
     conf = dsl.PipelineConf()
     conf.set_default_pod_node_selector(
-        os.getenv('TRAIN_NODE_KEY'), os.getenv('TRAIN_NODE_VAL'))
+        os.getenv('NODE_KEY'), os.getenv('NODE_VAL'))
     kfp.compiler.Compiler().compile(
         cluster_pipeline, gen_pipe.pipe_path,
         pipeline_conf=conf)
